#[repr(transparent)]pub struct Intenclr(pub u32);Expand description
Interrupt Enable Clear register.
Tuple Fields
0: u32Implementations
Sourceimpl Intenclr
impl Intenclr
Sourcepub const fn mstpendingclr(&self) -> bool
pub const fn mstpendingclr(&self) -> bool
Master Pending interrupt clear. Writing 1 to this bit clears the corresponding bit in the INTENSET register if implemented.
Sourcepub const fn set_mstpendingclr(&mut self, val: bool)
pub const fn set_mstpendingclr(&mut self, val: bool)
Master Pending interrupt clear. Writing 1 to this bit clears the corresponding bit in the INTENSET register if implemented.
Sourcepub const fn mstarblossclr(&self) -> bool
pub const fn mstarblossclr(&self) -> bool
Master Arbitration Loss interrupt clear.
Sourcepub const fn set_mstarblossclr(&mut self, val: bool)
pub const fn set_mstarblossclr(&mut self, val: bool)
Master Arbitration Loss interrupt clear.
Sourcepub const fn mstststperrclr(&self) -> bool
pub const fn mstststperrclr(&self) -> bool
Master Start/Stop Error interrupt clear.
Sourcepub const fn set_mstststperrclr(&mut self, val: bool)
pub const fn set_mstststperrclr(&mut self, val: bool)
Master Start/Stop Error interrupt clear.
Sourcepub const fn slvpendingclr(&self) -> bool
pub const fn slvpendingclr(&self) -> bool
Slave Pending interrupt clear.
Sourcepub const fn set_slvpendingclr(&mut self, val: bool)
pub const fn set_slvpendingclr(&mut self, val: bool)
Slave Pending interrupt clear.
Sourcepub const fn slvnotstrclr(&self) -> bool
pub const fn slvnotstrclr(&self) -> bool
Slave Not Stretching interrupt clear.
Sourcepub const fn set_slvnotstrclr(&mut self, val: bool)
pub const fn set_slvnotstrclr(&mut self, val: bool)
Slave Not Stretching interrupt clear.
Sourcepub const fn slvdeselclr(&self) -> bool
pub const fn slvdeselclr(&self) -> bool
Slave Deselect interrupt clear.
Sourcepub const fn set_slvdeselclr(&mut self, val: bool)
pub const fn set_slvdeselclr(&mut self, val: bool)
Slave Deselect interrupt clear.
Sourcepub const fn set_monrdyclr(&mut self, val: bool)
pub const fn set_monrdyclr(&mut self, val: bool)
Monitor data Ready interrupt clear.
Sourcepub const fn set_monovclr(&mut self, val: bool)
pub const fn set_monovclr(&mut self, val: bool)
Monitor Overrun interrupt clear.
Sourcepub const fn monidleclr(&self) -> bool
pub const fn monidleclr(&self) -> bool
Monitor Idle interrupt clear.
Sourcepub const fn set_monidleclr(&mut self, val: bool)
pub const fn set_monidleclr(&mut self, val: bool)
Monitor Idle interrupt clear.
Sourcepub const fn eventtimeoutclr(&self) -> bool
pub const fn eventtimeoutclr(&self) -> bool
Event time-out interrupt clear.
Sourcepub const fn set_eventtimeoutclr(&mut self, val: bool)
pub const fn set_eventtimeoutclr(&mut self, val: bool)
Event time-out interrupt clear.
Sourcepub const fn scltimeoutclr(&self) -> bool
pub const fn scltimeoutclr(&self) -> bool
SCL time-out interrupt clear.
Sourcepub const fn set_scltimeoutclr(&mut self, val: bool)
pub const fn set_scltimeoutclr(&mut self, val: bool)
SCL time-out interrupt clear.