#[repr(transparent)]pub struct Slvadr3(pub u32);Expand description
Slave address register.
Tuple Fields
0: u32Implementations
Sourceimpl Slvadr3
impl Slvadr3
Sourcepub const fn sadisable(&self) -> Slvadr3Sadisable
pub const fn sadisable(&self) -> Slvadr3Sadisable
Slave Address n Disable.
Sourcepub const fn set_sadisable(&mut self, val: Slvadr3Sadisable)
pub const fn set_sadisable(&mut self, val: Slvadr3Sadisable)
Slave Address n Disable.
Sourcepub const fn slvadr(&self) -> u8
pub const fn slvadr(&self) -> u8
Slave Address. Seven bit slave address that is compared to received addresses if enabled.
Sourcepub const fn set_slvadr(&mut self, val: u8)
pub const fn set_slvadr(&mut self, val: u8)
Slave Address. Seven bit slave address that is compared to received addresses if enabled.