nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Slvctl

Struct Slvctl 

#[repr(transparent)]
pub struct Slvctl(pub u32);
Slave control register.

Tuple Fields

0: u32

Implementations

Source

impl Slvctl

pub const fn slvcontinue(&self) -> Slvcontinue

Slave Continue.

pub const fn set_slvcontinue(&mut self, val: Slvcontinue)

Slave Continue.

pub const fn slvnack(&self) -> Slvnack

Slave NACK.

pub const fn set_slvnack(&mut self, val: Slvnack)

Slave NACK.

pub const fn slvdma(&self) -> bool

Slave DMA enable.

pub const fn set_slvdma(&mut self, val: bool)

Slave DMA enable.

pub const fn autoack(&self) -> Autoack

Automatic Acknowledge.When this bit is set, it will cause an I2C header which matches SLVADR0 and the direction set by AUTOMATCHREAD to be ACKed immediately; this is used with DMA to allow processing of the data without intervention. If this bit is clear and a header matches SLVADR0, the behavior is controlled by AUTONACK in the SLVADR0 register: allowing NACK or interrupt.

pub const fn set_autoack(&mut self, val: Autoack)

Automatic Acknowledge.When this bit is set, it will cause an I2C header which matches SLVADR0 and the direction set by AUTOMATCHREAD to be ACKed immediately; this is used with DMA to allow processing of the data without intervention. If this bit is clear and a header matches SLVADR0, the behavior is controlled by AUTONACK in the SLVADR0 register: allowing NACK or interrupt.

pub const fn automatchread(&self) -> Automatchread

When AUTOACK is set, this bit controls whether it matches a read or write request on the next header with an address matching SLVADR0. Since DMA needs to be configured to match the transfer direction, the direction needs to be specified. This bit allows a direction to be chosen for the next operation.

pub const fn set_automatchread(&mut self, val: Automatchread)

When AUTOACK is set, this bit controls whether it matches a read or write request on the next header with an address matching SLVADR0. Since DMA needs to be configured to match the transfer direction, the direction needs to be specified. This bit allows a direction to be chosen for the next operation.