#[repr(transparent)]pub struct Slvctl(pub u32);Expand description
Slave control register.
Tuple Fields
0: u32Implementations
Sourceimpl Slvctl
impl Slvctl
Sourcepub const fn slvcontinue(&self) -> Slvcontinue
pub const fn slvcontinue(&self) -> Slvcontinue
Slave Continue.
Sourcepub const fn set_slvcontinue(&mut self, val: Slvcontinue)
pub const fn set_slvcontinue(&mut self, val: Slvcontinue)
Slave Continue.
Sourcepub const fn set_slvnack(&mut self, val: Slvnack)
pub const fn set_slvnack(&mut self, val: Slvnack)
Slave NACK.
Sourcepub const fn set_slvdma(&mut self, val: bool)
pub const fn set_slvdma(&mut self, val: bool)
Slave DMA enable.
Sourcepub const fn autoack(&self) -> Autoack
pub const fn autoack(&self) -> Autoack
Automatic Acknowledge.When this bit is set, it will cause an I2C header which matches SLVADR0 and the direction set by AUTOMATCHREAD to be ACKed immediately; this is used with DMA to allow processing of the data without intervention. If this bit is clear and a header matches SLVADR0, the behavior is controlled by AUTONACK in the SLVADR0 register: allowing NACK or interrupt.
Sourcepub const fn set_autoack(&mut self, val: Autoack)
pub const fn set_autoack(&mut self, val: Autoack)
Automatic Acknowledge.When this bit is set, it will cause an I2C header which matches SLVADR0 and the direction set by AUTOMATCHREAD to be ACKed immediately; this is used with DMA to allow processing of the data without intervention. If this bit is clear and a header matches SLVADR0, the behavior is controlled by AUTONACK in the SLVADR0 register: allowing NACK or interrupt.
Sourcepub const fn automatchread(&self) -> Automatchread
pub const fn automatchread(&self) -> Automatchread
When AUTOACK is set, this bit controls whether it matches a read or write request on the next header with an address matching SLVADR0. Since DMA needs to be configured to match the transfer direction, the direction needs to be specified. This bit allows a direction to be chosen for the next operation.
Sourcepub const fn set_automatchread(&mut self, val: Automatchread)
pub const fn set_automatchread(&mut self, val: Automatchread)
When AUTOACK is set, this bit controls whether it matches a read or write request on the next header with an address matching SLVADR0. Since DMA needs to be configured to match the transfer direction, the direction needs to be specified. This bit allows a direction to be chosen for the next operation.